@@ -34,14 +34,14 @@ struct spvm_method {
   int32_t mortal_stack_length;
   int32_t tmp_vars_length;
   int8_t is_class_method;
-  int8_t is_init;
+  int8_t is_init_method;
   int8_t is_destructor;
   int8_t is_enum;
   int8_t is_precompile;
   int8_t is_native;
-  int8_t is_anon;
   int8_t is_required;
   int8_t access_control_type;
+  SPVM_OP* op_anon_method_field_var_decl_start;
 };
 
 SPVM_METHOD* SPVM_METHOD_new(SPVM_COMPILER* compiler);
