@@ -7,6 +7,9 @@
 #include <stdint.h>
 #include <stddef.h>
 
+struct spvm_mutex;
+typedef struct spvm_mutex SPVM_MUTEX;
+
 // spvm_class_file.h
 struct spvm_class_file;
 typedef struct spvm_class_file SPVM_CLASS_FILE;
